@@ -1,5 +1,5 @@
 labkey.selectRows <- function(baseUrl, folderPath, schemaName, queryName, viewName=NULL, colSelect=NULL, 
-						maxRows=NULL, rowOffset=NULL, colSort=NULL, colFilter=NULL, stripAllHidden=TRUE)
+			maxRows=NULL, rowOffset=NULL, colSort=NULL, colFilter=NULL, showHidden=FALSE)
 {	
 ## Empty string/NULL checking
 if(is.null(viewName)==FALSE) {char <- nchar(viewName); if(char<1){viewName<-NULL}}
@@ -8,21 +8,18 @@ if(is.null(maxRows)==FALSE) {char <- nchar(maxRows); if(char<1){maxRows<-NULL}}
 if(is.null(rowOffset)==FALSE) {char <- nchar(rowOffset); if(char<1){rowOffset<-NULL}}
 if(is.null(colSort)==FALSE) {char <- nchar(colSort); if(char<1){colSort<-NULL}}
 if(is.null(colFilter)==FALSE) {char <- nchar(colFilter[1]); if(char<1){colFilter<-NULL}}
-if(is.null(stripAllHidden)==FALSE) {char <- nchar(stripAllHidden); if(char<1){stripAllHidden<-NULL}}
-
+if(is.null(showHidden)==FALSE) {char <- nchar(showHidden); if(char<1){showHidden<-FALSE}}
 
 ## Error if any of baseUrl, folderPath, schemName or queryName are missing
 if(exists("baseUrl")==FALSE || exists("folderPath")==FALSE || exists("schemaName")==FALSE || exists("queryName")==FALSE)
 stop (paste("A value must be specified for each of baseUrl, folderPath, schemaName and queryName.")) 
 
-
 ## URL encoding of schema, query, view and folder path
 if(length(grep("%",schemaName))<1) {schemaName <- URLencode(schemaName)}
 if(length(grep("%",queryName))<1) {queryName <- URLencode(queryName)}
 if(length(grep("%",folderPath))<1) {folderPath <- URLencode(folderPath)}
 if(is.null(viewName)==FALSE) {if(length(grep("%",viewName))<1) viewName <- URLencode(viewName)}
 
-
 ## Format colSelect
 if(is.null(colSelect)==FALSE)
     {   lencolSel <- length(colSelect)
@@ -30,7 +27,6 @@ if(is.null(colSelect)==FALSE)
         for(i in 1:length(colSelect)) holder <-paste(holder,URLencode(colSelect[i]),",",sep="")
         colSelect <- substr(holder, 1, nchar(holder)-1)}
 
-
 ## Formatting
 baseUrl <- gsub("[\\]", "/", baseUrl)
 folderPath <- gsub("[\\]", "/", folderPath)
@@ -38,7 +34,6 @@ if(substr(baseUrl, nchar(baseUrl), nchar(baseUrl))!="/"){baseUrl <- paste(baseUr
 if(substr(folderPath, nchar(folderPath), nchar(folderPath))!="/"){folderPath <- paste(folderPath,"/",sep="")}
 if(substr(folderPath, 1, 1)!="/"){folderPath <- paste("/",folderPath,sep="")}
 
-
 ## Construct url 
 myurl <- paste(baseUrl,"query",folderPath,"selectRows.api?schemaName=",schemaName,"&query.queryName=",queryName,sep="","&apiVersion=8.3")
 if(is.null(viewName)==FALSE) {myurl <- paste(myurl,"&query.viewName=",viewName,sep="")}
@@ -49,7 +44,6 @@ if(is.null(colSort)==FALSE) {myurl <- paste(myurl,"&query.sort=",colSort,sep="")
 if(is.null(colFilter)==FALSE) {for(j in 1:length(colFilter)) myurl <- paste(myurl,"&query.",colFilter[j],sep="")}
 if(is.null(maxRows)==TRUE) {myurl <- paste(myurl,"&query.showRows=all",sep="")}
 
-
 ## Set options 
 reader <- basicTextGatherer()
 header <- basicTextGatherer()
@@ -57,8 +51,8 @@ myopts <- curlOptions(writefunction=reader$update, headerfunction=header$update,
 
 ## Http get
 handle <- getCurlHandle()
-var1 <- ifcookie()
-if(var1) {mydata <- getURI(myurl, .opts=myopts, cookie=paste(labkey.sessionCookieName,"=",labkey.sessionCookieContents,sep=""))} else {mydata <- getURI(myurl, .opts=myopts, curl=handle)} 
+clist <- ifcookie()
+if(clist$Cvalue==1) {mydata <- getURI(myurl, .opts=myopts, cookie=paste(clist$Cname,"=",clist$Ccont,sep=""))} else {mydata <- getURI(myurl, .opts=myopts, curl=handle)} 
 
 ## Error checking, decode data and return data frame
 h <- parseHeader(header$value())
@@ -73,7 +67,7 @@ if(status>=400)
         {decode <- fromJSON(mydata); message<-decode$exception; stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))} else
     {stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}}
 
-newdata <- makeDF(mydata, colSelect, stripAllHidden)
+newdata <- makeDF(mydata, colSelect, showHidden)
 
 
 ## Check for less columns returned than requested
